Kaj je OiRA? | OiRA

Teme

# Kaj je OiRA?

## Ali prvič uporabljate orodje OiRA?

Pripravili smo kratko uvodno predstavitev ocene tveganja in kako vam je lahko orodje OiRA v pomoč pri njeni pripravi.

## Kaj je ocena tveganja?

Ocena tveganja je osnova za uspešno upravljanje varnosti in zdravja pri delu ter je ključnega pomena za zmanjšanje nezgod, povezanih z delom, in poklicnih bolezni. Če je dobro opravljena, lahko izboljša varnost in zdravje na delovnem mestu, pa tudi uspešnost poslovanja na splošno.

Varnost in zdravje delavcev sta v Evropi zaščitena z ocenjevanjem in upravljanjem tveganj pri delu. Delodajalci so pravno odgovorni za zagotavljanje varnosti in zdravja delavcev v vseh vidikih, povezanih z delom, in za izvedbo ocene tveganja. Vsako podjetje mora torej izvesti oceno tveganja in pripraviti načrt ukrepov. Za izvedbo uspešne ocene tveganja na delovnem mestu morajo vse zadevne osebe jasno razumeti:

- pravni okvir in zasnove;
- postopek, ki se uporablja za ocenjevanje tveganj;
- vlogo glavnih akterjev, vključenih v postopek.

Delavci in/ali njihovi predstavniki imajo pravico, da se z njimi posvetuje o ureditvah, ki jih je treba izvesti, in da sodelujejo pri oceni tveganja.

Za več informacij o oceni tveganja in sodelovanju delavcev in/ali njihovih predstavnikov v postopku ocenjevanja tveganj obiščite spletno mesto OiRA.

## Kaj je OiRA?

OiRA je spletno interaktivno orodje za izdelavo ocene tveganj. Je spletna aplikacija, s katero lahko ocenite tveganja za varnost in zdravje na svojem delovnem mestu.

## Komu je orodje OiRA namenjeno?

Orodje OiRA lahko uporabi kdor koli za oceno tveganj, povezanih z varnostjo in zdravjem, ki so morda prisotna na njegovem delovnem mestu.

Vendar je orodje OiRA zasnovano tako, da je najbolj primerno za manjša podjetja. Orodje OiRA je bilo razvito posebej za to, da tem podjetjem olajša ocenjevanje tveganj pri delu in pripravo dokumentirane ocene tveganja, vključno z načrtom ukrepov, prilagojenim zahtevam poslovne enote.

## Kaj moram storiti?

V postopku ocenjevanja tveganj z orodjem OiRA je treba izvesti naslednje korake:

- priprava: nekatera orodja vključujejo vprašanja o profilu, na podlagi katerih boste orodje lahko prilagodili posebnostim vaše poslovne enote. Ko odgovorite na vprašanja o profilu, se orodje prilagodi vašim posebnim okoliščinam in prikaže module, ki se uporabljajo zanje;

- vključevanje: delavci bi morali biti dejavno vključeni pri pripravi vsake ocene tveganja. V orodju lahko natisnete celotno besedilo ocene tveganja ali dele tega besedila, da bi o ugotovitvah obvestili delavce in pridobili njihove povratne informacije;

- identifikacija tveganj: orodje OiRA prikaže opis vrste morebitnih nevarnosti ali težav za varnost in zdravje, ki bi lahko bile prisotne na vašem delovnem mestu. Nato izberete, ali so takšne nevarnosti ali težave prisotne, tako da na izjave/vprašanja odgovorite z ,da‘ ali ,ne‘. Vprašanje lahko tudi pustite neodgovorjeno in nanj odgovorite pozneje;

- ocena: nekatera orodja od vas zahtevajo, da prednostno razvrstite tveganja, ki ste jih opredelili. To lahko storite na več načinov, ki so odvisni od odločitev nacionalnih partnerjev/razvijalcev orodja OiRA in njihovega specifičnega pristopa. Nekatera orodja tudi samodejno prednostno razvrstijo tveganja v ozadju, to razvrstitev pa lahko razveljavite;

- načrt ukrepov: orodje vas pozove, da za vsako opredeljeno tveganje izberete en ukrep za odpravo ali zmanjšanje tveganja ali več takih ukrepov. Večina orodij vam predlaga nekatere ukrepe. Vedno pa lahko vnesete tudi svoje ukrepe;

- poročilo: pravno ste odgovorni, da svojo oceno tveganja dokumentirate. V oddelku za poročilo so na voljo različna poročila, s katerimi lahko spremljate napredek pri vaši oceni tveganja in izvajanje ukrepov, ki ste se jih odločili izvesti za odpravo ali zmanjšanje opredeljenih tveganj.

## Kako dolgo traja postopek ocene tveganja?

Nemogoče je navesti, kako dolgo bo na splošno trajal postopek ocene tveganja, saj se orodja razlikujejo glede na sektor in državo.

Lahko pa za oceno porabite čas, ki ga imate na voljo, nato pa nadaljujete, kjer ste končali, ko vam to ustreza.

## Zakaj se moram registrirati?

Pred začetkom svoje prve ocene tveganja ste najprej pozvani, da ustvarite račun OiRA, kar lahko storite enostavno in hitro.

Registracija vam omogoča, da se kadar koli enostavno prijavite in dostopate do prejšnjih ocen ali začnete nove.

Če ste registrirani uporabnik, lahko tudi kadar koli pridobite natisnjeno, točno in posodobljeno oceno tveganja.

## Ali se moram pripraviti?

Za uporabo orodja niso potrebne nobene posebne priprave, nekaj časa pa morate nameniti razmisleku, kdo bo izvedel oceno tveganja in kako bodo v ta postopek vključeni delavci.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More